@@ -15,13 +15,7 @@ def detect_text(path):
     texts = response.text_annotations
     print('Texts:')
 
-    for text in texts:
-        print('\n"{}"'.format(text.description))
-
-        vertices = (['({},{})'.format(vertex.x, vertex.y)
-                    for vertex in text.bounding_poly.vertices])
-
-        print('bounds: {}'.format(','.join(vertices)))
+    print('{}'.format(texts[0].description))
 
     if response.error.message:
         raise Exception(
@@ -32,8 +26,11 @@ def detect_text(path):
 
 @click.command()
 @click.argument('filename')
-def detect(fname):
-    detect_text(fname)
+def detect(filename):
+    detect_text(filename)
+
+def main():
+    detect()
 
 if __name__ == '__main__':
-    detect()
+    main()
